from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Data.Xml.Dom
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class DtdEntity(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IDtdEntity
    _classid_ = 'Windows.Data.Xml.Dom.DtdEntity'
    @winrt_mixinmethod
    def get_PublicId(self: win32more.Windows.Data.Xml.Dom.IDtdEntity) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_SystemId(self: win32more.Windows.Data.Xml.Dom.IDtdEntity) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_NotationName(self: win32more.Windows.Data.Xml.Dom.IDtdEntity) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    NotationName = property(get_NotationName, None)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
    PublicId = property(get_PublicId, None)
    SystemId = property(get_SystemId, None)
class DtdNotation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IDtdNotation
    _classid_ = 'Windows.Data.Xml.Dom.DtdNotation'
    @winrt_mixinmethod
    def get_PublicId(self: win32more.Windows.Data.Xml.Dom.IDtdNotation) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_SystemId(self: win32more.Windows.Data.Xml.Dom.IDtdNotation) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
    PublicId = property(get_PublicId, None)
    SystemId = property(get_SystemId, None)
class IDtdEntity(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IDtdEntity'
    _iid_ = Guid('{6a0b5ffc-63b4-480f-9e6a-8a92816aade4}')
    @winrt_commethod(6)
    def get_PublicId(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_SystemId(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(8)
    def get_NotationName(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    NotationName = property(get_NotationName, None)
    PublicId = property(get_PublicId, None)
    SystemId = property(get_SystemId, None)
class IDtdNotation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IDtdNotation'
    _iid_ = Guid('{8cb4e04d-6d46-4edb-ab73-df83c51ad397}')
    @winrt_commethod(6)
    def get_PublicId(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def get_SystemId(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    PublicId = property(get_PublicId, None)
    SystemId = property(get_SystemId, None)
class IXmlAttribute(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlAttribute'
    _iid_ = Guid('{ac144aa4-b4f1-4db6-b206-8a22c308db0a}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Specified(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_Value(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def put_Value(self, value: WinRT_String) -> Void: ...
    Name = property(get_Name, None)
    Specified = property(get_Specified, None)
    Value = property(get_Value, put_Value)
class IXmlCDataSection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlCDataSection'
    _iid_ = Guid('{4d04b46f-c8bd-45b4-8899-0400d7c2c60f}')
class IXmlCharacterData(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlCharacterData'
    _iid_ = Guid('{132e42ab-4e36-4df6-b1c8-0ce62fd88b26}')
    @winrt_commethod(6)
    def get_Data(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Data(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_Length(self) -> UInt32: ...
    @winrt_commethod(9)
    def SubstringData(self, offset: UInt32, count: UInt32) -> WinRT_String: ...
    @winrt_commethod(10)
    def AppendData(self, data: WinRT_String) -> Void: ...
    @winrt_commethod(11)
    def InsertData(self, offset: UInt32, data: WinRT_String) -> Void: ...
    @winrt_commethod(12)
    def DeleteData(self, offset: UInt32, count: UInt32) -> Void: ...
    @winrt_commethod(13)
    def ReplaceData(self, offset: UInt32, count: UInt32, data: WinRT_String) -> Void: ...
    Data = property(get_Data, put_Data)
    Length = property(get_Length, None)
class IXmlComment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlComment'
    _iid_ = Guid('{bca474d5-b61f-4611-9cac-2e92e3476d47}')
class IXmlDocument(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDocument'
    _iid_ = Guid('{f7f3a506-1e87-42d6-bcfb-b8c809fa5494}')
    @winrt_commethod(6)
    def get_Doctype(self) -> win32more.Windows.Data.Xml.Dom.XmlDocumentType: ...
    @winrt_commethod(7)
    def get_Implementation(self) -> win32more.Windows.Data.Xml.Dom.XmlDomImplementation: ...
    @winrt_commethod(8)
    def get_DocumentElement(self) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_commethod(9)
    def CreateElement(self, tagName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_commethod(10)
    def CreateDocumentFragment(self) -> win32more.Windows.Data.Xml.Dom.XmlDocumentFragment: ...
    @winrt_commethod(11)
    def CreateTextNode(self, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlText: ...
    @winrt_commethod(12)
    def CreateComment(self, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlComment: ...
    @winrt_commethod(13)
    def CreateProcessingInstruction(self, target: WinRT_String, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlProcessingInstruction: ...
    @winrt_commethod(14)
    def CreateAttribute(self, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_commethod(15)
    def CreateEntityReference(self, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlEntityReference: ...
    @winrt_commethod(16)
    def GetElementsByTagName(self, tagName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_commethod(17)
    def CreateCDataSection(self, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlCDataSection: ...
    @winrt_commethod(18)
    def get_DocumentUri(self) -> WinRT_String: ...
    @winrt_commethod(19)
    def CreateAttributeNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, qualifiedName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_commethod(20)
    def CreateElementNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, qualifiedName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_commethod(21)
    def GetElementById(self, elementId: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_commethod(22)
    def ImportNode(self, node: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    Doctype = property(get_Doctype, None)
    DocumentElement = property(get_DocumentElement, None)
    DocumentUri = property(get_DocumentUri, None)
    Implementation = property(get_Implementation, None)
class IXmlDocumentFragment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDocumentFragment'
    _iid_ = Guid('{e2ea6a96-0c21-44a5-8bc9-9e4a262708ec}')
class IXmlDocumentIO(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDocumentIO'
    _iid_ = Guid('{6cd0e74e-ee65-4489-9ebf-ca43e87ba637}')
    @winrt_commethod(6)
    def LoadXml(self, xml: WinRT_String) -> Void: ...
    @winrt_commethod(7)
    def LoadXmlWithSettings(self, xml: WinRT_String, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> Void: ...
    @winrt_commethod(8)
    def SaveToFileAsync(self, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
class IXmlDocumentIO2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDocumentIO2'
    _iid_ = Guid('{5d034661-7bd8-4ad5-9ebf-81e6347263b1}')
    @winrt_commethod(6)
    def LoadXmlFromBuffer(self, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_commethod(7)
    def LoadXmlFromBufferWithSettings(self, buffer: win32more.Windows.Storage.Streams.IBuffer, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> Void: ...
class IXmlDocumentStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDocumentStatics'
    _iid_ = Guid('{5543d254-d757-4b79-9539-232b18f50bf1}')
    @winrt_commethod(6)
    def LoadFromUriAsync(self, uri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    @winrt_commethod(7)
    def LoadFromUriWithSettingsAsync(self, uri: win32more.Windows.Foundation.Uri, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    @winrt_commethod(8)
    def LoadFromFileAsync(self, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    @winrt_commethod(9)
    def LoadFromFileWithSettingsAsync(self, file: win32more.Windows.Storage.IStorageFile, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
class IXmlDocumentType(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDocumentType'
    _iid_ = Guid('{f7342425-9781-4964-8e94-9b1c6dfc9bc7}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Entities(self) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_commethod(8)
    def get_Notations(self) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    Entities = property(get_Entities, None)
    Name = property(get_Name, None)
    Notations = property(get_Notations, None)
class IXmlDomImplementation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlDomImplementation'
    _iid_ = Guid('{6de58132-f11d-4fbb-8cc6-583cba93112f}')
    @winrt_commethod(6)
    def HasFeature(self, feature: WinRT_String, version: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
class IXmlElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlElement'
    _iid_ = Guid('{2dfb8a1f-6b10-4ef8-9f83-efcce8faec37}')
    @winrt_commethod(6)
    def get_TagName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetAttribute(self, attributeName: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(8)
    def SetAttribute(self, attributeName: WinRT_String, attributeValue: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def RemoveAttribute(self, attributeName: WinRT_String) -> Void: ...
    @winrt_commethod(10)
    def GetAttributeNode(self, attributeName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_commethod(11)
    def SetAttributeNode(self, newAttribute: win32more.Windows.Data.Xml.Dom.XmlAttribute) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_commethod(12)
    def RemoveAttributeNode(self, attributeNode: win32more.Windows.Data.Xml.Dom.XmlAttribute) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_commethod(13)
    def GetElementsByTagName(self, tagName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_commethod(14)
    def SetAttributeNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, qualifiedName: WinRT_String, value: WinRT_String) -> Void: ...
    @winrt_commethod(15)
    def GetAttributeNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, localName: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(16)
    def RemoveAttributeNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, localName: WinRT_String) -> Void: ...
    @winrt_commethod(17)
    def SetAttributeNodeNS(self, newAttribute: win32more.Windows.Data.Xml.Dom.XmlAttribute) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_commethod(18)
    def GetAttributeNodeNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, localName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    TagName = property(get_TagName, None)
class IXmlEntityReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlEntityReference'
    _iid_ = Guid('{2e2f47bc-c3d0-4ccf-bb86-0ab8c36a61cf}')
class IXmlLoadSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlLoadSettings'
    _iid_ = Guid('{58aa07a8-fed6-46f7-b4c5-fb1ba72108d6}')
    @winrt_commethod(6)
    def get_MaxElementDepth(self) -> UInt32: ...
    @winrt_commethod(7)
    def put_MaxElementDepth(self, value: UInt32) -> Void: ...
    @winrt_commethod(8)
    def get_ProhibitDtd(self) -> Boolean: ...
    @winrt_commethod(9)
    def put_ProhibitDtd(self, value: Boolean) -> Void: ...
    @winrt_commethod(10)
    def get_ResolveExternals(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_ResolveExternals(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_ValidateOnParse(self) -> Boolean: ...
    @winrt_commethod(13)
    def put_ValidateOnParse(self, value: Boolean) -> Void: ...
    @winrt_commethod(14)
    def get_ElementContentWhiteSpace(self) -> Boolean: ...
    @winrt_commethod(15)
    def put_ElementContentWhiteSpace(self, value: Boolean) -> Void: ...
    ElementContentWhiteSpace = property(get_ElementContentWhiteSpace, put_ElementContentWhiteSpace)
    MaxElementDepth = property(get_MaxElementDepth, put_MaxElementDepth)
    ProhibitDtd = property(get_ProhibitDtd, put_ProhibitDtd)
    ResolveExternals = property(get_ResolveExternals, put_ResolveExternals)
    ValidateOnParse = property(get_ValidateOnParse, put_ValidateOnParse)
class IXmlNamedNodeMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Data.Xml.Dom.IXmlNode]]
    _classid_ = 'Windows.Data.Xml.Dom.IXmlNamedNodeMap'
    _iid_ = Guid('{b3a69eb0-aab0-4b82-a6fa-b1453f7c021b}')
    @winrt_commethod(6)
    def get_Length(self) -> UInt32: ...
    @winrt_commethod(7)
    def Item(self, index: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(8)
    def GetNamedItem(self, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def SetNamedItem(self, node: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(10)
    def RemoveNamedItem(self, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(11)
    def GetNamedItemNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(12)
    def RemoveNamedItemNS(self, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(13)
    def SetNamedItemNS(self, node: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    Length = property(get_Length, None)
class IXmlNode(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlNode'
    _iid_ = Guid('{1c741d59-2122-47d5-a856-83f3d4214875}')
    @winrt_commethod(6)
    def get_NodeValue(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(7)
    def put_NodeValue(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_commethod(8)
    def get_NodeType(self) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_commethod(9)
    def get_NodeName(self) -> WinRT_String: ...
    @winrt_commethod(10)
    def get_ParentNode(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(11)
    def get_ChildNodes(self) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_commethod(12)
    def get_FirstChild(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(13)
    def get_LastChild(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(14)
    def get_PreviousSibling(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(15)
    def get_NextSibling(self) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(16)
    def get_Attributes(self) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_commethod(17)
    def HasChildNodes(self) -> Boolean: ...
    @winrt_commethod(18)
    def get_OwnerDocument(self) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_commethod(19)
    def InsertBefore(self, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(20)
    def ReplaceChild(self, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(21)
    def RemoveChild(self, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(22)
    def AppendChild(self, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(23)
    def CloneNode(self, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(24)
    def get_NamespaceUri(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(25)
    def get_LocalName(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(26)
    def get_Prefix(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(27)
    def Normalize(self) -> Void: ...
    @winrt_commethod(28)
    def put_Prefix(self, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class IXmlNodeList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Data.Xml.Dom.IXmlNode]]
    _classid_ = 'Windows.Data.Xml.Dom.IXmlNodeList'
    _iid_ = Guid('{8c60ad77-83a4-4ec1-9c54-7ba429e13da6}')
    @winrt_commethod(6)
    def get_Length(self) -> UInt32: ...
    @winrt_commethod(7)
    def Item(self, index: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    Length = property(get_Length, None)
class IXmlNodeSelector(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlNodeSelector'
    _iid_ = Guid('{63dbba8b-d0db-4fe1-b745-f9433afdc25b}')
    @winrt_commethod(6)
    def SelectSingleNode(self, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(7)
    def SelectNodes(self, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_commethod(8)
    def SelectSingleNodeNS(self, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_commethod(9)
    def SelectNodesNS(self, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
class IXmlNodeSerializer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlNodeSerializer'
    _iid_ = Guid('{5cc5b382-e6dd-4991-abef-06d8d2e7bd0c}')
    @winrt_commethod(6)
    def GetXml(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_InnerText(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_InnerText(self, value: WinRT_String) -> Void: ...
    InnerText = property(get_InnerText, put_InnerText)
class IXmlProcessingInstruction(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlProcessingInstruction'
    _iid_ = Guid('{2707fd1e-1e92-4ece-b6f4-26f069078ddc}')
    @winrt_commethod(6)
    def get_Target(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Data(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Data(self, value: WinRT_String) -> Void: ...
    Data = property(get_Data, put_Data)
    Target = property(get_Target, None)
class IXmlText(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Data.Xml.Dom.IXmlText'
    _iid_ = Guid('{f931a4cb-308d-4760-a1d5-43b67450ac7e}')
    @winrt_commethod(6)
    def SplitText(self, offset: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlText: ...
class NodeType(Enum, Int32):
    Invalid = 0
    ElementNode = 1
    AttributeNode = 2
    TextNode = 3
    DataSectionNode = 4
    EntityReferenceNode = 5
    EntityNode = 6
    ProcessingInstructionNode = 7
    CommentNode = 8
    DocumentNode = 9
    DocumentTypeNode = 10
    DocumentFragmentNode = 11
    NotationNode = 12
class XmlAttribute(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlAttribute
    _classid_ = 'Windows.Data.Xml.Dom.XmlAttribute'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Data.Xml.Dom.IXmlAttribute) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Specified(self: win32more.Windows.Data.Xml.Dom.IXmlAttribute) -> Boolean: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Data.Xml.Dom.IXmlAttribute) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Value(self: win32more.Windows.Data.Xml.Dom.IXmlAttribute, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    Name = property(get_Name, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
    Specified = property(get_Specified, None)
    Value = property(get_Value, put_Value)
class XmlCDataSection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlCDataSection
    _classid_ = 'Windows.Data.Xml.Dom.XmlCDataSection'
    @winrt_mixinmethod
    def SplitText(self: win32more.Windows.Data.Xml.Dom.IXmlText, offset: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlText: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData) -> UInt32: ...
    @winrt_mixinmethod
    def SubstringData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32) -> WinRT_String: ...
    @winrt_mixinmethod
    def AppendData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def InsertData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DeleteData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32) -> Void: ...
    @winrt_mixinmethod
    def ReplaceData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    Data = property(get_Data, put_Data)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    Length = property(get_Length, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class XmlComment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlComment
    _classid_ = 'Windows.Data.Xml.Dom.XmlComment'
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData) -> UInt32: ...
    @winrt_mixinmethod
    def SubstringData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32) -> WinRT_String: ...
    @winrt_mixinmethod
    def AppendData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def InsertData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DeleteData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32) -> Void: ...
    @winrt_mixinmethod
    def ReplaceData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    Data = property(get_Data, put_Data)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    Length = property(get_Length, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class XmlDocument(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlDocument
    _classid_ = 'Windows.Data.Xml.Dom.XmlDocument'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Data.Xml.Dom.XmlDocument.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def get_Doctype(self: win32more.Windows.Data.Xml.Dom.IXmlDocument) -> win32more.Windows.Data.Xml.Dom.XmlDocumentType: ...
    @winrt_mixinmethod
    def get_Implementation(self: win32more.Windows.Data.Xml.Dom.IXmlDocument) -> win32more.Windows.Data.Xml.Dom.XmlDomImplementation: ...
    @winrt_mixinmethod
    def get_DocumentElement(self: win32more.Windows.Data.Xml.Dom.IXmlDocument) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_mixinmethod
    def CreateElement(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, tagName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_mixinmethod
    def CreateDocumentFragment(self: win32more.Windows.Data.Xml.Dom.IXmlDocument) -> win32more.Windows.Data.Xml.Dom.XmlDocumentFragment: ...
    @winrt_mixinmethod
    def CreateTextNode(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlText: ...
    @winrt_mixinmethod
    def CreateComment(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlComment: ...
    @winrt_mixinmethod
    def CreateProcessingInstruction(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, target: WinRT_String, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlProcessingInstruction: ...
    @winrt_mixinmethod
    def CreateAttribute(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def CreateEntityReference(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlEntityReference: ...
    @winrt_mixinmethod
    def GetElementsByTagName(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, tagName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def CreateCDataSection(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, data: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlCDataSection: ...
    @winrt_mixinmethod
    def get_DocumentUri(self: win32more.Windows.Data.Xml.Dom.IXmlDocument) -> WinRT_String: ...
    @winrt_mixinmethod
    def CreateAttributeNS(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, qualifiedName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def CreateElementNS(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, qualifiedName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_mixinmethod
    def GetElementById(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, elementId: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlElement: ...
    @winrt_mixinmethod
    def ImportNode(self: win32more.Windows.Data.Xml.Dom.IXmlDocument, node: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def LoadXml(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentIO, xml: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def LoadXmlWithSettings(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentIO, xml: WinRT_String, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> Void: ...
    @winrt_mixinmethod
    def SaveToFileAsync(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentIO, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def LoadXmlFromBuffer(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentIO2, buffer: win32more.Windows.Storage.Streams.IBuffer) -> Void: ...
    @winrt_mixinmethod
    def LoadXmlFromBufferWithSettings(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentIO2, buffer: win32more.Windows.Storage.Streams.IBuffer, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> Void: ...
    @winrt_classmethod
    def LoadFromUriAsync(cls: win32more.Windows.Data.Xml.Dom.IXmlDocumentStatics, uri: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    @winrt_classmethod
    def LoadFromUriWithSettingsAsync(cls: win32more.Windows.Data.Xml.Dom.IXmlDocumentStatics, uri: win32more.Windows.Foundation.Uri, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    @winrt_classmethod
    def LoadFromFileAsync(cls: win32more.Windows.Data.Xml.Dom.IXmlDocumentStatics, file: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    @winrt_classmethod
    def LoadFromFileWithSettingsAsync(cls: win32more.Windows.Data.Xml.Dom.IXmlDocumentStatics, file: win32more.Windows.Storage.IStorageFile, loadSettings: win32more.Windows.Data.Xml.Dom.XmlLoadSettings) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Data.Xml.Dom.XmlDocument]: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    Doctype = property(get_Doctype, None)
    DocumentElement = property(get_DocumentElement, None)
    DocumentUri = property(get_DocumentUri, None)
    FirstChild = property(get_FirstChild, None)
    Implementation = property(get_Implementation, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class XmlDocumentFragment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlDocumentFragment
    _classid_ = 'Windows.Data.Xml.Dom.XmlDocumentFragment'
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class XmlDocumentType(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlDocumentType
    _classid_ = 'Windows.Data.Xml.Dom.XmlDocumentType'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentType) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Entities(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentType) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def get_Notations(self: win32more.Windows.Data.Xml.Dom.IXmlDocumentType) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    Entities = property(get_Entities, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    Name = property(get_Name, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    Notations = property(get_Notations, None)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class XmlDomImplementation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlDomImplementation
    _classid_ = 'Windows.Data.Xml.Dom.XmlDomImplementation'
    @winrt_mixinmethod
    def HasFeature(self: win32more.Windows.Data.Xml.Dom.IXmlDomImplementation, feature: WinRT_String, version: win32more.Windows.Win32.System.WinRT.IInspectable) -> Boolean: ...
class XmlElement(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlElement
    _classid_ = 'Windows.Data.Xml.Dom.XmlElement'
    @winrt_mixinmethod
    def get_TagName(self: win32more.Windows.Data.Xml.Dom.IXmlElement) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetAttribute(self: win32more.Windows.Data.Xml.Dom.IXmlElement, attributeName: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def SetAttribute(self: win32more.Windows.Data.Xml.Dom.IXmlElement, attributeName: WinRT_String, attributeValue: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def RemoveAttribute(self: win32more.Windows.Data.Xml.Dom.IXmlElement, attributeName: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetAttributeNode(self: win32more.Windows.Data.Xml.Dom.IXmlElement, attributeName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def SetAttributeNode(self: win32more.Windows.Data.Xml.Dom.IXmlElement, newAttribute: win32more.Windows.Data.Xml.Dom.XmlAttribute) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def RemoveAttributeNode(self: win32more.Windows.Data.Xml.Dom.IXmlElement, attributeNode: win32more.Windows.Data.Xml.Dom.XmlAttribute) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def GetElementsByTagName(self: win32more.Windows.Data.Xml.Dom.IXmlElement, tagName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SetAttributeNS(self: win32more.Windows.Data.Xml.Dom.IXmlElement, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, qualifiedName: WinRT_String, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def GetAttributeNS(self: win32more.Windows.Data.Xml.Dom.IXmlElement, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, localName: WinRT_String) -> WinRT_String: ...
    @winrt_mixinmethod
    def RemoveAttributeNS(self: win32more.Windows.Data.Xml.Dom.IXmlElement, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, localName: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def SetAttributeNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlElement, newAttribute: win32more.Windows.Data.Xml.Dom.XmlAttribute) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def GetAttributeNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlElement, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, localName: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlAttribute: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
    TagName = property(get_TagName, None)
class XmlEntityReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlEntityReference
    _classid_ = 'Windows.Data.Xml.Dom.XmlEntityReference'
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
class XmlLoadSettings(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings
    _classid_ = 'Windows.Data.Xml.Dom.XmlLoadSettings'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Data.Xml.Dom.XmlLoadSettings.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Data.Xml.Dom.XmlLoadSettings: ...
    @winrt_mixinmethod
    def get_MaxElementDepth(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings) -> UInt32: ...
    @winrt_mixinmethod
    def put_MaxElementDepth(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings, value: UInt32) -> Void: ...
    @winrt_mixinmethod
    def get_ProhibitDtd(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_ProhibitDtd(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ResolveExternals(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_ResolveExternals(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ValidateOnParse(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_ValidateOnParse(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ElementContentWhiteSpace(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings) -> Boolean: ...
    @winrt_mixinmethod
    def put_ElementContentWhiteSpace(self: win32more.Windows.Data.Xml.Dom.IXmlLoadSettings, value: Boolean) -> Void: ...
    ElementContentWhiteSpace = property(get_ElementContentWhiteSpace, put_ElementContentWhiteSpace)
    MaxElementDepth = property(get_MaxElementDepth, put_MaxElementDepth)
    ProhibitDtd = property(get_ProhibitDtd, put_ProhibitDtd)
    ResolveExternals = property(get_ResolveExternals, put_ResolveExternals)
    ValidateOnParse = property(get_ValidateOnParse, put_ValidateOnParse)
class XmlNamedNodeMap(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Data.Xml.Dom.IXmlNode]]
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap
    _classid_ = 'Windows.Data.Xml.Dom.XmlNamedNodeMap'
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap) -> UInt32: ...
    @winrt_mixinmethod
    def Item(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, index: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetNamedItem(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SetNamedItem(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, node: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveNamedItem(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetNamedItemNS(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveNamedItemNS(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, namespaceUri: win32more.Windows.Win32.System.WinRT.IInspectable, name: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SetNamedItemNS(self: win32more.Windows.Data.Xml.Dom.IXmlNamedNodeMap, node: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode], index: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode], value: win32more.Windows.Data.Xml.Dom.IXmlNode, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode], startIndex: UInt32, items: FillArray[win32more.Windows.Data.Xml.Dom.IXmlNode]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Data.Xml.Dom.IXmlNode]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Data.Xml.Dom.IXmlNode]: ...
    Length = property(get_Length, None)
    Size = property(get_Size, None)
class XmlNodeList(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[SequenceProtocol[win32more.Windows.Data.Xml.Dom.IXmlNode]]
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlNodeList
    _classid_ = 'Windows.Data.Xml.Dom.XmlNodeList'
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.Data.Xml.Dom.IXmlNodeList) -> UInt32: ...
    @winrt_mixinmethod
    def Item(self: win32more.Windows.Data.Xml.Dom.IXmlNodeList, index: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def GetAt(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode], index: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Size(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode]) -> UInt32: ...
    @winrt_mixinmethod
    def IndexOf(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode], value: win32more.Windows.Data.Xml.Dom.IXmlNode, index: POINTER(UInt32)) -> Boolean: ...
    @winrt_mixinmethod
    def GetMany(self: win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Data.Xml.Dom.IXmlNode], startIndex: UInt32, items: FillArray[win32more.Windows.Data.Xml.Dom.IXmlNode]) -> UInt32: ...
    @winrt_mixinmethod
    def First(self: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Data.Xml.Dom.IXmlNode]) -> win32more.Windows.Foundation.Collections.IIterator[win32more.Windows.Data.Xml.Dom.IXmlNode]: ...
    Length = property(get_Length, None)
    Size = property(get_Size, None)
class XmlProcessingInstruction(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlProcessingInstruction
    _classid_ = 'Windows.Data.Xml.Dom.XmlProcessingInstruction'
    @winrt_mixinmethod
    def get_Target(self: win32more.Windows.Data.Xml.Dom.IXmlProcessingInstruction) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Data.Xml.Dom.IXmlProcessingInstruction) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.Data.Xml.Dom.IXmlProcessingInstruction, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    Data = property(get_Data, put_Data)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)
    Target = property(get_Target, None)
class XmlText(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Data.Xml.Dom.IXmlText
    _classid_ = 'Windows.Data.Xml.Dom.XmlText'
    @winrt_mixinmethod
    def SplitText(self: win32more.Windows.Data.Xml.Dom.IXmlText, offset: UInt32) -> win32more.Windows.Data.Xml.Dom.IXmlText: ...
    @winrt_mixinmethod
    def get_Data(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Data(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_Length(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData) -> UInt32: ...
    @winrt_mixinmethod
    def SubstringData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32) -> WinRT_String: ...
    @winrt_mixinmethod
    def AppendData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def InsertData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def DeleteData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32) -> Void: ...
    @winrt_mixinmethod
    def ReplaceData(self: win32more.Windows.Data.Xml.Dom.IXmlCharacterData, offset: UInt32, count: UInt32, data: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def put_NodeValue(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def get_NodeType(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.NodeType: ...
    @winrt_mixinmethod
    def get_NodeName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ParentNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_ChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def get_FirstChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_LastChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_PreviousSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NextSibling(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlNamedNodeMap: ...
    @winrt_mixinmethod
    def HasChildNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Boolean: ...
    @winrt_mixinmethod
    def get_OwnerDocument(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.XmlDocument: ...
    @winrt_mixinmethod
    def InsertBefore(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def ReplaceChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode, referenceChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def RemoveChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, childNode: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def AppendChild(self: win32more.Windows.Data.Xml.Dom.IXmlNode, newChild: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def CloneNode(self: win32more.Windows.Data.Xml.Dom.IXmlNode, deep: Boolean) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def get_NamespaceUri(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_LocalName(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def get_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def Normalize(self: win32more.Windows.Data.Xml.Dom.IXmlNode) -> Void: ...
    @winrt_mixinmethod
    def put_Prefix(self: win32more.Windows.Data.Xml.Dom.IXmlNode, value: win32more.Windows.Win32.System.WinRT.IInspectable) -> Void: ...
    @winrt_mixinmethod
    def SelectSingleNode(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodes(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def SelectSingleNodeNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.IXmlNode: ...
    @winrt_mixinmethod
    def SelectNodesNS(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSelector, xpath: WinRT_String, namespaces: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Data.Xml.Dom.XmlNodeList: ...
    @winrt_mixinmethod
    def GetXml(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_InnerText(self: win32more.Windows.Data.Xml.Dom.IXmlNodeSerializer, value: WinRT_String) -> Void: ...
    Attributes = property(get_Attributes, None)
    ChildNodes = property(get_ChildNodes, None)
    Data = property(get_Data, put_Data)
    FirstChild = property(get_FirstChild, None)
    InnerText = property(get_InnerText, put_InnerText)
    LastChild = property(get_LastChild, None)
    Length = property(get_Length, None)
    LocalName = property(get_LocalName, None)
    NamespaceUri = property(get_NamespaceUri, None)
    NextSibling = property(get_NextSibling, None)
    NodeName = property(get_NodeName, None)
    NodeType = property(get_NodeType, None)
    NodeValue = property(get_NodeValue, put_NodeValue)
    OwnerDocument = property(get_OwnerDocument, None)
    ParentNode = property(get_ParentNode, None)
    Prefix = property(get_Prefix, put_Prefix)
    PreviousSibling = property(get_PreviousSibling, None)


make_ready(__name__)
